@@ -1,9 +1,8 @@
-import dataclasses
 from pathlib import Path
 from typing import Dict, Optional
 
-import dacite
 import yaml
+
 from racetrack_client.log.context_error import wrap_context
 from racetrack_client.client_config.client_config import ClientConfig, Credentials
 from racetrack_client.log.logs import get_logger
@@ -20,11 +19,7 @@ def load_client_config() -> ClientConfig:
     try:
         with path.open() as file:
             config_dict = yaml.load(file, Loader=yaml.FullLoader)
-            config = dacite.from_dict(
-                data_class=ClientConfig,
-                data=config_dict,
-                config=dacite.Config(cast=[]),
-            )
+            config = ClientConfig.parse_obj(config_dict)
 
             logger.info(f'client config loaded from {path}')
             return config
@@ -37,15 +32,11 @@ def load_credentials_from_dict(credentials_dict: Optional[Dict]) -> Optional[Cre
         return None
 
     with wrap_context('parsing credentials'):
-        return dacite.from_dict(
-            data_class=Credentials,
-            data=credentials_dict,
-            config=dacite.Config(cast=[]),
-        )
+        return Credentials.parse_obj(credentials_dict)
 
 
 def save_client_config(config: ClientConfig):
-    data_dict = dataclasses.asdict(config)
+    data_dict = config.dict()
 
     dir_path = Path.home() / '.racetrack'
     dir_path.mkdir(parents=True, exist_ok=True)
