@@ -1,22 +1,21 @@
 import os
 from pathlib import Path
-from typing import List, Type, TypeVar
+from typing import Type, TypeVar
 
-import dacite
+from pydantic import BaseModel
 import yaml
 
 from racetrack_client.log.logs import get_logger
 
-T = TypeVar("T")
-
 logger = get_logger(__name__)
 
+T = TypeVar("T", bound=BaseModel)
 
-def load_config(clazz: Type[T], cast_types: List[Type] = None) -> T:
+
+def load_config(clazz: Type[T]) -> T:
     """
     Load general configuration from YAML file given in CONFIG_FILE environment var or load default config.
-    :param clazz: dataclass config type that should be loaded
-    :param cast_types: list of types that should be called to create an instance of a field type from the input data
+    :param clazz: pydantic.BaseModel type that should be loaded
     :return: configuration object of given "clazz" type
     """
     config_file_path = os.environ.get('CONFIG_FILE')
@@ -31,11 +30,7 @@ def load_config(clazz: Type[T], cast_types: List[Type] = None) -> T:
     try:
         with path.open() as file:
             config_dict = yaml.load(file, Loader=yaml.FullLoader)
-            config = dacite.from_dict(
-                data_class=clazz,
-                data=config_dict,
-                config=dacite.Config(cast=cast_types or []),
-            )
+            config = clazz.parse_obj(config_dict)
 
             logger.info(f'config loaded from {config_file_path}: {config}')
             return config
